#! /bin/sh
#-----------------------------------------------------------------------------
# /tmp/install.sh - davfs2 installation
#
# Copyright (c) 2001-2019  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation   :  2010-01-28 holbru
# Last update:  $Id: install.sh 63106 2019-02-11 13:22:24Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#-----------------------------------------------------------------------------

# read eislib etc.
. /var/install/include/eislib
. /var/install/include/jedlib

module_name='davfs2'

# debug mode: true/false
#debug=true
if ${debug:-false}
then
    exec 2>/tmp/${module_name}-$(basename ${0})-trace$$.log
    set -x
    ask_debug=true
    export ask_debug
fi

myecho --pack ${module_name} --info "running install.sh ..."

# update shared library file
update_jedlib ${module_name}

# set access rights
chmod 4755 /usr/sbin/mount.davfs
chmod 0755 /usr/sbin/umount.davfs

# create directories
mkdir -p -m 0755 /etc/davfs2/certs
mkdir -p -m 0755 /var/cache/davfs2

# create user and group
user='davfs2'
group='davfs2'
uid=''
gid=''
name='user for davfs2 deamon'
homedir=''
shell='/bin/false'

# check group
grep -q "^${group}:" /etc/group

if [ $? -ne 0 ]
then
    myecho --pack ${module_name} "adding group '${group}' ..."
    /var/install/bin/add-group ${group} ${gid}
fi

# read GID from file
gid=`grep "^${group}:" /etc/group | cut -d: -f3`

# check if user exists
grep -q "^${user}:" /etc/passwd

if [ $? -ne 0 ]
then
    # create new user
    myecho --pack ${module_name} "adding user '${user}' ..."
    /var/install/bin/add-user ${user} "*" "${uid}" "${gid}" "${name}" "${homedir}" "${shell}"
else
    # user exists, check if group has properly been set
    gidusr=`grep "^${user}:" /etc/passwd | cut -d: -f4`

    if [ "${gidusr}" != "${gid}" ]
    then
        gname=`grep ":${gidusr}:" /etc/group | cut -d: -f1`

        if [ "${gname}" != "${group}" ]
        then
            myecho --pack ${module_name} --warn "Attention, the default group had been set to '${gname}', it should be '${group}'!"
            myecho --pack ${module_name} "modifying group of user '${user}', '${gname}' -> '${group}' ..."
            /var/install/bin/modify-user -g "${user}" "${group}"
        fi
    fi

    # user exists, make sure that shell has properly set
    sname=`grep "^${user}:" /etc/passwd | cut -d: -f7`

    if [ "${sname}" != "${shell}" ]
    then
        myecho --pack ${module_name} "modifying shell of user '${user}', '${name}' -> '${shell}' ..."
        /var/install/bin/modify-user -s "${user}" "${shell}"
    fi
fi

# check password to make sure that the account has not been disabled
grep -q "^${user}:\!" /etc/shadow

if [ $? -eq 0 ]
then
    passwd -d ${user}
fi

# set access rights for home directory
homedir=`grep "^${user}:" /etc/passwd | cut -d: -f6`
chown -R ${user}  ${homedir}
chgrp -R ${group} ${homedir}
chmod 0700 ${homedir}

#if [ ! -f ${HOME}/.davfs2 ]
#then
#    mkdir -p ${HOME}/.davfs2
#fi
#
#chmod 0700 ${HOME}/.davfs2

#----------------------------------------------------------------------------
# end
#----------------------------------------------------------------------------
exit 0
