#! /bin/sh
#-----------------------------------------------------------------------------
# /tmp/preinstall.sh - davfs2 preinstallation
#
# Creation   :  2010-01-28 holbru
# Last update:  $Id: preinstall.sh 63102 2019-02-11 13:01:21Z jed $
#
# Copyright (c) 2001-2019  The Eisfair Team, team(at)eisfair(dot)org
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#-----------------------------------------------------------------------------

# set packages name
pgmname=`basename $0`
module_name='davfs2'

# extract shared library file from archive
# to be able to use the myecho command
archivefile=`find /tmp -maxdepth 1 -type l -name "${module_name}.tar.*" ! -name "*.info" | head -n1`

if [ -n "${archivefile}" ]
then
    if [ -s "${archivefile}" ]
    then
        tar xjf ${archivefile} var/install/include/jedlib.${module_name} -C /

        srcfile=/var/install/include/jedlib.${module_name}
        destfile=/var/install/include/jedlib

        if [ -f ${srcfile} ]
        then
            if [ -f ${destfile} ]
            then
                srcver=`/bin/sh ${srcfile} version`
                destver=`/bin/sh ${destfile} version`

                if [ -n "${destver}" ]
                then
                    # version number exists - compare version numbers
                    if [ `echo "${srcver} > ${destver}" | bc` -eq 1 ]
                    then
                        # update file
                        echo "updating shared library file (${destver}->${srcver}) ..."
                        mv -v ${srcfile} ${destfile}
                    fi
                else
                    # no version number exists - update file
                    echo "updating shared library file ..."
                    mv -v ${srcfile} ${destfile}
                fi
            else
                # file doesn't exist - update file
                echo "updating shared library file ..."
                mv -v ${srcfile} ${destfile}
            fi
        fi
    fi
fi

# read eislib etc.
. /var/install/include/eislib
. /var/install/include/jedlib

myecho --pack ${module_name} --info "running preinstall.sh ..."

#----------------------------------------------------------------------------
# Delete NOT allowed OLD deinstall scripts
#----------------------------------------------------------------------------
if [ -f "/var/install/deinstall/${module_name}" ]
then
    # deinstall old software
    myecho --pack ${module_name} "deinstalling previously installed software ..."
    /usr/bin/eisman uninstall --update --auto --quiet ${module_name}
fi

#----------------------------------------------------------------------------
# end
#----------------------------------------------------------------------------
exit 0
